@@ -328,6 +328,10 @@ class FunctionParser(Parser):
         self.gen_name += "." + node.attr  # Add the function name
         self.raw_name += "." + node.attr
 
+    def visit_Subscript(self, node):
+        # jump over subscripts for the sake of method calls
+        self.visit(node.value)
+
     def visit_Name(self, node):
         self.gen_name = self.mappings.get(node.id) or node.id
         self.raw_name = node.id
@@ -346,8 +350,7 @@ class FunctionParser(Parser):
                 'args': IndexedDict((n['name'], n) for n in [*args, *keywords]),
                 #'pos_args': args,
                 #'keywords': keywords,
-                'name': self.raw_name,
-                '_spec1': (node, node.args, node.keywords, self.raw_name)
+                'name': self.raw_name
                 }
 
     def get_pos_arg_part(self, arg, indx_pos):
