@@ -2,8 +2,6 @@ from .test_mc import test_mc
 from .test_or import test_or
 from .test_with import test_with
 from .test_comp import test_list_comp
-from .test_comp import test_dict_comp
-from .test_comp import test_generator_exp
 from .test_import import test_import
 from .test_object import test_object
 from .test_correct import test_correct
@@ -11,14 +9,11 @@ from .test_if_else import test_if_else
 from .test_if_else import test_if_exp
 from .test_for_loop import test_for_loop
 from .test_function import test_function
-from .test_function import test_print
 from .test_function import test_function_v2
-from .test_try_except import test_try_except
 from .test_data_frame import test_data_frame
 from .test_while_loop import test_while_loop
 from .test_student_typed import test_student_typed
 from .test_object_accessed import test_object_accessed
 from .test_output_contains import test_output_contains
-from .test_lambda_function import test_lambda_function
 from .test_expression import test_expression_output, test_expression_result, test_object_after_expression
 from .test_function_definition import test_function_definition
